mailr24372 - in /branches/frame_order_cleanup: lib/structure/internal/ lib/structure/represent/ pipe_control/


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 01, 2014 - 12:18:
Author: bugman
Date: Tue Jul  1 12:18:03 2014
New Revision: 24372

URL: http://svn.gna.org/viewcvs/relax?rev=24372&view=rev
Log:
Renaming of the residues of the cone geometric representation.

The cone apex or centre is now the CNC residue, the cone axis is now CNX and 
the cone edge is now
CNE.  These used to be APX, AXE, and EDG respectively.  The aim is to make 
these names 100% specific
to the cone object so that they can be more easily selected for manipulating 
the representation and
so that they are more easily identifiable.  The internal structural object 
_get_chemical_name()
function now returns a description for each of these.  Note that the main 
cone object is still named
CON.


Modified:
    branches/frame_order_cleanup/lib/structure/internal/object.py
    branches/frame_order_cleanup/lib/structure/represent/cone.py
    branches/frame_order_cleanup/pipe_control/pymol_control.py

Modified: branches/frame_order_cleanup/lib/structure/internal/object.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_cleanup/lib/structure/internal/object.py?rev=24372&r1=24371&r2=24372&view=diff
==============================================================================
--- branches/frame_order_cleanup/lib/structure/internal/object.py       
(original)
+++ branches/frame_order_cleanup/lib/structure/internal/object.py       Tue 
Jul  1 12:18:03 2014
@@ -199,10 +199,13 @@
          | AXS    | Tensor axes                                    |
          | SIM    | Monte Carlo simulation tensor axes             |
          | PIV    | Pivot point                                    |
-         | CON    | Cone object                                    |
          | AVE    | Average vector                                 |
          | RTX    | Axis of the rotor geometric object             |
          | RTB    | Propeller blades of the rotor geometric object |
+         | CON    | Cone object                                    |
+         | CNC    | Apex or centre of the cone geometric object    |
+         | CNX    | Axis of the cone geometric object              |
+         | CNE    | Edge of the cone geometric object              |
          |________|________________________________________________|
 
         For any other residues, no description is returned.
@@ -220,10 +223,13 @@
             "AXS": "Tensor axes",
             "SIM": "Monte Carlo simulation tensor axes",
             "PIV": "Pivot point",
-            "CON": "Cone object",
             "AVE": "Average vector",
             "RTX": "Axis of the rotor geometric object",
-            "RTB": "Propeller blades of the rotor geometric object"
+            "RTB": "Propeller blades of the rotor geometric object",
+            "CON": "Cone object",
+            "CNC": "Apex or centre of the cone geometric object",
+            "CNX": "Axis of the cone geometric object",
+            "CNE": "Edge of the cone geometric object",
         }
 
         # Return the description, if one exists.

Modified: branches/frame_order_cleanup/lib/structure/represent/cone.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_cleanup/lib/structure/represent/cone.py?rev=24372&r1=24371&r2=24372&view=diff
==============================================================================
--- branches/frame_order_cleanup/lib/structure/represent/cone.py        
(original)
+++ branches/frame_order_cleanup/lib/structure/represent/cone.py        Tue 
Jul  1 12:18:03 2014
@@ -259,19 +259,19 @@
 
     # The axis.
     if axis_flag:
-        # Add the apex.
-        mol.atom_add(pdb_record='HETATM', atom_num=start_atom, 
atom_name='R', res_name='APX', res_num=start_res, pos=apex, element='C')
+        # Add the apex (or centre point).
+        mol.atom_add(pdb_record='HETATM', atom_num=start_atom, 
atom_name='R', res_name='CNC', res_num=start_res, pos=apex, element='C')
 
         # Generate the axis vectors.
         print("\nGenerating the axis vectors.")
-        res_num = generate_vector_residues(mol=mol, vector=dot(R, axis), 
atom_name='Axis', res_name_vect='AXE', res_num=start_res+1, origin=apex, 
scale=scale)
+        res_num = generate_vector_residues(mol=mol, vector=dot(R, axis), 
atom_name='Axis', res_name_vect='CNX', res_num=start_res+1, origin=apex, 
scale=scale)
 
     # Generate the cone outer edge.
     print("\nGenerating the cone outer edge.")
     edge_start_atom = 1
     if hasattr(mol, 'atom_num') and len(mol.atom_num):
         edge_start_atom = mol.atom_num[-1]+1
-    cone_edge(mol=mol, cone_obj=cone_obj, res_name='EDG', 
res_num=start_res+2, apex=apex, R=R, scale=scale, inc=inc, 
distribution=distribution)
+    cone_edge(mol=mol, cone_obj=cone_obj, res_name='CNE', 
res_num=start_res+2, apex=apex, R=R, scale=scale, inc=inc, 
distribution=distribution)
 
     # Generate the cone cap, and stitch it to the cone edge.
     print("\nGenerating the cone cap.")

Modified: branches/frame_order_cleanup/pipe_control/pymol_control.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_cleanup/pipe_control/pymol_control.py?rev=24372&r1=24371&r2=24372&view=diff
==============================================================================
--- branches/frame_order_cleanup/pipe_control/pymol_control.py  (original)
+++ branches/frame_order_cleanup/pipe_control/pymol_control.py  Tue Jul  1 
12:18:03 2014
@@ -563,8 +563,8 @@
     if id == None:
         raise RelaxError("The PyMOL object ID must be supplied.")
 
-    # Select the AVE, AXE, and SIM residues.
-    pymol_obj.exec_cmd("select (%s & resn AVE,AXE,SIM)" % id)
+    # Select the AVE, CNX, and SIM residues.
+    pymol_obj.exec_cmd("select (%s & resn AVE,CNX,SIM)" % id)
 
     # Show the vector as a stick.
     pymol_obj.exec_cmd("show stick, 'sele'")
@@ -573,7 +573,7 @@
     pymol_obj.exec_cmd("color cyan, 'sele'")
 
     # Select the atom used for labelling.
-    pymol_obj.exec_cmd("select (%s & resn AVE,AXE,SIM and symbol N)" % id)
+    pymol_obj.exec_cmd("select (%s & resn AVE,CNX,SIM and symbol N)" % id)
 
     # Hide the atom.
     pymol_obj.exec_cmd("hide ('sele')")
@@ -596,8 +596,8 @@
     if id == None:
         raise RelaxError("The PyMOL object ID must be supplied.")
 
-    # Select the CON and EDG residues.
-    pymol_obj.exec_cmd("select (%s & resn CON,EDG)" % id)
+    # Select the CON and CNE residues.
+    pymol_obj.exec_cmd("select (%s & resn CON,CNE)" % id)
 
     # Hide everything.
     pymol_obj.exec_cmd("hide ('sele')")




Related Messages


Powered by MHonArc, Updated Tue Jul 01 13:00:02 2014